@@ -4,3 +4,5 @@
 1. `vkquivk.bot.Bot`
 1. `vkquick.api.API`
 """
+bot = None
+api = None
