@@ -2,5 +2,8 @@
 Валидаторы для реакций
 """
 from .base import Validator
-from .cmd import Cmd
+
 from .action import Action
+from .cmd import Cmd
+from .chat_only import ChatOnly
+from .direct_only import DirectOnly
