@@ -8,9 +8,6 @@ class ChatOnly(Validator):
     которое должно быть отправленно только в беседе
     """
 
-    def __init__(self, *types):
-        self.types = types
-
     def isvalid(self, event, com, bin_stack):
         if event.object.message.peer_id > PEER:
             return (True, "")
